/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include <dawn/dawn.h>
#include "../../../display/shader.h"
#include "../../../display/primitive.h"
#include "../../../display/primitives/quad.h"
#include "../../../display/spritebatch.h"
#include "../../../display/gui/font.h"
#include "../../../display/framebuffer.h"
#include "../../../display/camera.h"
#include "../../../display/primitives/cube.h"
#include "../../../display/tileset.h"
#include "../../../util/math.h"
#include "../model/pokertable.h"

/**
 * Prepare the Hold'em Game Renderer.
 */
void holdemRenderInit();

/**
 * Render the Texas Hold'em Game.
 */
void holdemRender();

/**
 * Look at a specific seat
 * 
 * @param camera Camera to adjust.
 * @param seat Seat to look at.
 */
void holdemRenderLookSeat(camera_t *camera, uint8_t seat);

/**
 * Look at a specific seats hand.
 * 
 * @param camera Camera to adjust.
 * @param seat Seats hand to look at.
 */
void holdemRenderLookHand(camera_t *camera, uint8_t seat);

/**
 * Renders a Teax Hold'em player
 * 
 * @param seat Seat that the player sits at.
 */
void holdemRenderPlayer(uint8_t seat);

// void holdemRenderCard(card_t card,
//   float x, float y, float z, float pitch, float yaw, float roll
// );

void holdemRenderCard(uint8_t seat, card_t card);

void holdemRenderWorld();